==> gotemp-1.0.0.tar.gz: gotemp-1.0.0/gotemp/constants.py <==
# Thanks to the following for contributions that made this file possible:
# - Scott Tsai's gotemp-lights.py utility (2010)
#   https://gitorious.org/scottt/gotemp
CMD_ID_GET_STATUS = 0x10
CMD_ID_WRITE_LOCAL_NV_MEM_1BYTE = 0x11
CMD_ID_WRITE_LOCAL_NV_MEM_2BYTES = 0x12
CMD_ID_WRITE_LOCAL_NV_MEM_3BYTES = 0x13
CMD_ID_WRITE_LOCAL_NV_MEM_4BYTES = 0x14
CMD_ID_WRITE_LOCAL_NV_MEM_5BYTES = 0x15
CMD_ID_WRITE_LOCAL_NV_MEM_6BYTES = 0x16
CMD_ID_READ_LOCAL_NV_MEM = 0x17
CMD_ID_START_MEASUREMENTS = 0x18
CMD_ID_STOP_MEASUREMENTS = 0x19
CMD_ID_INIT = 0x1A
CMD_ID_SET_MEASUREMENT_PERIOD = 0x1B
CMD_ID_GET_MEASUREMENT_PERIOD = 0x1C
CMD_ID_SET_LED_STATE = 0x1D
CMD_ID_GET_LED_STATE = 0x1E
CMD_ID_GET_SERIAL_NUMBER = 0x20
# Commands defined above are supported by Skip, Jonah, and Cyclops, except that
# Cyclops does not support the serial # or the NV_MEM cmds.
# Skip extensions:
CMD_ID_SET_VIN_OFFSET_DAC = 0x1F
CMD_ID_WRITE_REMOTE_NV_MEM_1BYTE = 0x21
CMD_ID_WRITE_REMOTE_NV_MEM_2BYTES = 0x22
CMD_ID_WRITE_REMOTE_NV_MEM_3BYTES = 0x23
CMD_ID_WRITE_REMOTE_NV_MEM_4BYTES = 0x24
CMD_ID_WRITE_REMOTE_NV_MEM_5BYTES = 0x25
CMD_ID_WRITE_REMOTE_NV_MEM_6BYTES = 0x26
CMD_ID_READ_REMOTE_NV_MEM = 0x27
CMD_ID_GET_SENSOR_ID = 0x28
CMD_ID_SET_ANALOG_INPUT_CHANNEL = 0x29
CMD_ID_GET_ANALOG_INPUT_CHANNEL = 0x2A
CMD_ID_GET_VIN_OFFSET_DAC = 0x2B
CMD_ID_SPARE1 = 0x2C
CMD_ID_SPARE2 = 0x2D
CMD_ID_SPARE3 = 0x2E
CMD_ID_SPARE4 = 0x2F

LED_COLOR_RED = 0x40
LED_COLOR_GREEN = 0x80
LED_COLOR_ORANGE = 0x00

LED_BRIGHTNESS_MIN = 0x0
LED_BRIGHTNESS_MED = 0x08
LED_BRIGHTNESS_MAX = 0x10

# all command packets are 8 bytes
CMD_PACKET_SIZE = 8

==> gotemp-1.0.1.tar.gz: gotemp-1.0.1/gotemp/constants.py <==
# Thanks to the following for contributions that made this file possible:
# - Scott Tsai's gotemp-lights.py utility (2010)
#   https://gitorious.org/scottt/gotemp
CMD_ID_GET_STATUS = 0x10
CMD_ID_WRITE_LOCAL_NV_MEM_1BYTE = 0x11
CMD_ID_WRITE_LOCAL_NV_MEM_2BYTES = 0x12
CMD_ID_WRITE_LOCAL_NV_MEM_3BYTES = 0x13
CMD_ID_WRITE_LOCAL_NV_MEM_4BYTES = 0x14
CMD_ID_WRITE_LOCAL_NV_MEM_5BYTES = 0x15
CMD_ID_WRITE_LOCAL_NV_MEM_6BYTES = 0x16
CMD_ID_READ_LOCAL_NV_MEM = 0x17
CMD_ID_START_MEASUREMENTS = 0x18
CMD_ID_STOP_MEASUREMENTS = 0x19
CMD_ID_INIT = 0x1A
CMD_ID_SET_MEASUREMENT_PERIOD = 0x1B
CMD_ID_GET_MEASUREMENT_PERIOD = 0x1C
CMD_ID_SET_LED_STATE = 0x1D
CMD_ID_GET_LED_STATE = 0x1E
CMD_ID_GET_SERIAL_NUMBER = 0x20
# Commands defined above are supported by Skip, Jonah, and Cyclops, except that
# Cyclops does not support the serial # or the NV_MEM cmds.
# Skip extensions:
CMD_ID_SET_VIN_OFFSET_DAC = 0x1F
CMD_ID_WRITE_REMOTE_NV_MEM_1BYTE = 0x21
CMD_ID_WRITE_REMOTE_NV_MEM_2BYTES = 0x22
CMD_ID_WRITE_REMOTE_NV_MEM_3BYTES = 0x23
CMD_ID_WRITE_REMOTE_NV_MEM_4BYTES = 0x24
CMD_ID_WRITE_REMOTE_NV_MEM_5BYTES = 0x25
CMD_ID_WRITE_REMOTE_NV_MEM_6BYTES = 0x26
CMD_ID_READ_REMOTE_NV_MEM = 0x27
CMD_ID_GET_SENSOR_ID = 0x28
CMD_ID_SET_ANALOG_INPUT_CHANNEL = 0x29
CMD_ID_GET_ANALOG_INPUT_CHANNEL = 0x2A
CMD_ID_GET_VIN_OFFSET_DAC = 0x2B
CMD_ID_SPARE1 = 0x2C
CMD_ID_SPARE2 = 0x2D
CMD_ID_SPARE3 = 0x2E
CMD_ID_SPARE4 = 0x2F

LED_COLOR_BLACK = 0xC0
LED_COLOR_RED = 0x40
LED_COLOR_GREEN = 0x80
LED_COLOR_ORANGE = 0x00

LED_BRIGHTNESS_MIN = 0x0
LED_BRIGHTNESS_ORANGE = 0x04
LED_BRIGHTNESS_MAX = 0x0f

# all command packets are 8 bytes
CMD_PACKET_SIZE = 8
